Index: misc.php
===================================================================
--- misc.php	(revision 42716)
+++ misc.php	(working copy)
@@ -1146,10 +1146,10 @@
  * @since 4.9.0
  */
 function wp_admin_headers() {
-	$policy = 'same-origin';
+	$policy = 'strict-origin-when-cross-origin';
 
 	/**
 	 * Filters the admin referrer policy header value. Default 'same-origin'.
 	 *
 	 * @since 4.9.0
 	 * @link https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Referrer-Policy
@@ -1146,10 +1146,10 @@
 
 	/**
-	 * Filters the admin referrer policy header value. Default 'same-origin'.
+	 * Filters the admin referrer policy header value. Default 'strict-origin-when-cross-origin'.
 	 *
 	 * @since 4.9.0
